@@ -37,7 +37,6 @@
 #include <sys/mman.h>
 #include <assert.h>
 #include <urcu/compiler.h>
-#include <ulimit.h>
 #include <inttypes.h>
 
 #include <common/defaults.h>
@@ -250,7 +249,7 @@ void *thread_manage_health(void *data)
 	sock = lttcomm_create_unix_sock(health_unix_sock_path);
 	if (sock < 0) {
 		ERR("Unable to create health check Unix socket");
-		ret = -1;
+		err = -1;
 		goto error;
 	}
 
@@ -262,7 +261,7 @@ void *thread_manage_health(void *data)
 		if (ret < 0) {
 			ERR("Unable to set group on %s", health_unix_sock_path);
 			PERROR("chown");
-			ret = -1;
+			err = -1;
 			goto error;
 		}
 
@@ -271,7 +270,7 @@ void *thread_manage_health(void *data)
 		if (ret < 0) {
 			ERR("Unable to set permissions on %s", health_unix_sock_path);
 			PERROR("chmod");
-			ret = -1;
+			err = -1;
 			goto error;
 		}
 	}
