@@ -749,6 +749,7 @@ static struct lttcomm_sock *relay_socket_create(struct lttng_uri *uri)
 
 	ret = sock->ops->bind(sock);
 	if (ret < 0) {
+		PERROR("Failed to bind socket");
 		goto error;
 	}
 
@@ -1601,6 +1602,7 @@ static int relay_send_version(struct lttcomm_relayd_hdr *recv_hdr,
 {
 	int ret;
 	struct lttcomm_relayd_version reply, msg;
+	bool compatible = true;
 
 	conn->version_check_done = 1;
 
@@ -1625,9 +1627,7 @@ static int relay_send_version(struct lttcomm_relayd_hdr *recv_hdr,
 	if (reply.major != be32toh(msg.major)) {
 		DBG("Incompatible major versions (%u vs %u), deleting session",
 				reply.major, be32toh(msg.major));
-		connection_put(conn);
-		ret = 0;
-		goto end;
+		compatible = false;
 	}
 
 	conn->major = reply.major;
@@ -1646,6 +1646,11 @@ static int relay_send_version(struct lttcomm_relayd_hdr *recv_hdr,
 		ERR("Relay sending version");
 	}
 
+	if (!compatible) {
+		ret = -1;
+		goto end;
+	}
+
 	DBG("Version check done using protocol %u.%u", conn->major,
 			conn->minor);
 
