@@ -20,13 +20,13 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#define _GNU_SOURCE
 #define _LGPL_SOURCE
 #include <unistd.h>
 #include <sys/types.h>
 #include <stdint.h>
 #include <limits.h>
 #include <errno.h>
+#include <string.h>
 #include <lttng/health-internal.h>
 
 #include <bin/lttng-sessiond/health-sessiond.h>
